<?php 
/****************************************************************/
/*          e-mo.pl © 2017                                      */
/*          http://www.e-mo.com.pl                              */
/*          e-mail: info@e-mo.pl                                */
/*          produkt: Action2osCommerce                          */
/*          wersja: 1.9.7                                       */
/*          webserwis: oscGold                                  */
/*          sciezka: https://www.e-mo.com.pl/plikit,1918,533545b244d7d.php*/
/*          data: 2017-09-25                                    */
/*          godz: 10:45:11                                      */
/****************************************************************/


@require_once('source/produkty_cecha.php');
@require_once('source/sl_cechy.php');
@require_once('source/sl_cechy_typ.php');
@require_once('source/products.php');
@require_once('source/languages.php');

if(isset($_POST['reset']) && $_POST['reset']==1)
{
/*
	$cecha = new produkty_cecha();
	$cecha->Conn = $db->Conn;
	
	if(!$cecha->ResetIlosc())	
		echo '<przy name="Resetowanie cech"  error="1" msg="'.$cecha->errMsg[2].'" />';
	else 
*/
		echo '<przy name="Resetowanie cech"  error="0" msg="OK" />';
}
else
{
	$typ_1 = 0;
	$typ_2 = 0;
	
	$typ = new sl_cechy_typ();
	$typ->Conn =  $db->Conn;
	$typ->sct_Nazwa = str_replace('::amp::', '&',$_POST['cechaNazwa']);
	$typ->Jezyk = languages::Szukaj($db->Conn);

	$typ_1 = $typ->Sprawdz();

	if($typ_1 == 0 && !empty($_POST['cechaNazwa']))
	{
		if(!$typ->Dodaj())
			echo '<przy name="Dodawanie cechy 1"  error="1" msg="'.$typ->errMsg[2].'" />';
		else 
			echo '<przy name="Dodawanie cechy 1"  error="0" msg="OK" />';

		$typ_1 = $typ->sct_Id;
	}
	else
	{
		echo '<przy name="Cecha 1 istnieje"  error="0" msg="OK" />';
	}
	
	
	$typ2 = new sl_cechy_typ();
	$typ2->Conn =  $db->Conn;
	$typ2->sct_Nazwa = str_replace('::amp::', '&',$_POST['cechaNazwa2']);	
	$typ2->Jezyk = languages::Szukaj($db->Conn);
	$typ_2 = (int)$typ2->Sprawdz();
	
	if($typ_2 == 0 && !empty($_POST['cechaNazwa2']))
	{
		if($typ2->Dodaj())
			echo '<przy name="Dodawanie cechy 2"  error="1" msg="'.$typ2->errMsg[2].'" />';
		else 
			echo '<przy name="Dodawanie cechy 2"  error="0" msg="OK" />';
		
		$typ_2 = $typ2->sct_Id;
	}
	else
	{
		echo '<przy name="Cecha 2 istnieje"  error="0" msg="OK" />';
	}

	
	$cechaW = new sl_cechy();
	$cechaW->Conn = $db->Conn;
	$cechaW->c_Nazwa = str_replace('::amp::', '&',$_POST['cechaWartosc']);
	$cechaW->Jezyk = languages::Szukaj($db->Conn);
	$cechaW->c_Id=$cechaW->Sprawdz2();

	if($cechaW->c_Id <= 0 &&  !empty($_POST['cechaWartosc']))
	{
		if(!$cechaW->Dodaj())
			echo '<przy name="Dodawanie wartości cechy 1"  error="1" msg="'.$cechaW->errMsg[2].'" />';
		else 
			echo '<przy name="Dodawanie wartości cechy 1"  error="0" msg="OK" />';
		
		$cechaW->c_Id=$cechaW->Sprawdz2();
	}
	else 
	{
		echo '<przy name="Istnieje wartości cechy 1"  error="0" msg="OK" />';
	}
	
	$cecha_1 = $cechaW->c_Id;
	
	
	$cechaW2 = new sl_cechy();
	$cechaW2->Conn = $db->Conn;

	$cechaW2->c_Nazwa = str_replace('::amp::', '&',$_POST['cechaWartosc2']);
	$cechaW2->Jezyk =  languages::Szukaj($db->Conn);
	
	$cechaW2->c_Id=$cechaW2->Sprawdz2();

	if($cechaW2->c_Id <= 0 && !empty($_POST['cechaWartosc2']))
	{
		if(!$cechaW2->Dodaj())
			echo '<przy name="Dodawanie wartości cechy 2"  error="1" msg="'.$cechaW2->errMsg[2].'" />';
		else 
			echo '<przy name="Dodawanie wartości cechy 2"  error="0" msg="OK" />';

		$cechaW2->c_Id=(int)$cechaW2->Sprawdz2();
	}
	else 
	{
		echo '<przy name="Istnieje wartości cechy 2"  error="0" msg="OK" />';
	}

	$cecha_2 = $cechaW2->c_Id;
	
	echo '<cecha>'.$typ_1.':'.$cecha_1.'</cecha>';
	echo '<cecha2>'.$typ_2.':'.$cecha_2.'</cecha2>';

	$produkty = new products();
	$produkty->Conn = $db->Conn;

	$produkty->products_model =  $_POST['p_PN'];
	$produkty->products_id = $produkty->Sprawdz();
	
	$_cenyPrefix = true;

	if($produkty->products_id > 0)
	{
		$cecha = new produkty_cecha();
		$cecha->Conn = $db->Conn;		
		
		$cecha->products_options_id=(int)$typ_1;
		$cecha->products_options_values_id= (int)$cecha_1;
		$cecha->pc_Id = $cecha->Sprawdz();
		$_cenaMain = $cecha->GetPrice($produkty->products_id);
		$_cenaAtr = str_replace(',','.', $_POST['p_Cena']);
		$cecha->cena = abs($_cenaMain-$_cenaAtr);
		$cecha->plusik = ($_cenaMain-$_cenaAtr > 0 ) ? '-': '+';		
		$_cenyPrefix = false;
		
		if($cecha->pc_Id == 0)
		{
			if(!$cecha->DodajOptions())
				echo '<przy name="Dodawanie wartości cechy do cechy 1"  error="1" msg="'.$cecha->errMsg[2].'" />';
			else 
				echo '<przy name="Dodawanie wartości cechy do cechy 1"  error="0" msg="OK" />';
		}
		else 
		{
			echo '<przy name="Przypisanie wartości cechy do cechy 1 istnieje"  error="0" msg="OK" />';
		}

		$cecha->products_id = $produkty->products_id;
		$cecha->options_id = (int)$typ_1;
		$cecha->options_values_id = (int)$cecha_1;
		$cecha->a_Id = $cecha->SprawdzA();	
		
		if($cecha->a_Id == 0)
		{
			if($cecha->options_values_id > 0 && !$cecha->DodajAtrybuty())
				echo '<przy name="Dodawanie atrybutu 1 do produktu"  error="1" msg="'.$cecha->errMsg[2].'" />';
			else 
				echo '<przy name="Dodawanie atrybutu 1 do produktu"  error="0" msg="OK" />';
		}
		else 
		{

			if(!$cecha->ZmienAtrybuty())
			{
				echo '<przy name="Zmiana atrybutu 1 do produktu"  error="1" msg="'.$cecha->errMsg[2].'" />';
			}
			else 
				echo '<przy name="Zmiana atrybutu 1 do produktu"  error="0" msg="OK" />';

			echo '<przy name="Atrybut produktu istnieje"  error="0" msg="OK" />';
		}
		
		$cechaW2->c_Id=(int)$cechaW->Sprawdz2();
		$cecha2 = new produkty_cecha();
		$cecha2->Conn = $db->Conn;		
		
		$cecha2->products_options_id=(int)$typ_2;
		$cecha2->products_options_values_id= (int)$cecha_2;
		$cecha2->pc_Id = $cecha2->Sprawdz();	
		if($_cenyPrefix)
		{
			$_cenaMain = $cecha2->GetPrice($produkty->products_id);
			$_cenaAtr = str_replace(',','.', $_POST['p_Cena']);
			$cecha2->cena = abs($_cenaMain-$_cenaAtr);
			$cecha2->plusik = ($_cenaMain-$_cenaAtr > 0 ) ? '-': '+';
		}
		
		if($cecha2->pc_Id == 0)
		{
			if(!$cecha2->DodajOptions())
				echo '<przy name="Dodawanie wartości cechy do cechy 2"  error="1" msg="'.$cecha2->errMsg[2].'" />';
			else 
				echo '<przy name="Dodawanie wartości cechy do cechy 2 "  error="0" msg="OK" />';
		}
		else 
		{

			echo '<przy name="Przypisanie wartości cechy do cechy 2 istnieje"  error="0" msg="OK" />';
		}		
		
		$cecha2->products_id = $produkty->products_id;
		$cecha2->options_id = (int)$typ_2;
		$cecha2->options_values_id = (int)$cecha_2;
		$cecha2->a_Id = $cecha2->SprawdzA();	

		if($cecha2->a_Id == 0)
		{
			if($cecha2->options_values_id > 0 && !$cecha2->DodajAtrybuty())
				echo '<przy name="Dodawanie atrybutu 2 do produktu"  error="1" msg="'.$cecha2->errMsg[2].'" />';
			else 
				echo '<przy name="Dodawanie atrybutu 2 do produktu"  error="0" msg="OK" />';
		}
		else 
		{			
			if(!$cecha2->ZmienAtrybuty())
			{
				echo '<przy name="Zmiana atrybutu 2 do produktu"  error="1" msg="'.$cecha->errMsg[2].'" />';
			}
			else 
				echo '<przy name="Zmiana atrybutu 2 do produktu"  error="0" msg="OK" />';
			
			echo '<przy name="Atrybut 2 produktu istnieje"  error="0" msg="OK" />';
		}
		
		$cecha2->products_id = $produkty->products_id;
		$cecha2->ilosc =  $_POST['p_Ilosc'];
			
		if($typ_1 > 0 && $typ_2 > 0 && $typ_1 < $typ_2)
			$cecha2->atrybuty=sprintf("%s-%s,%s-%s", $typ_1,$cecha_1, $typ_2, $cecha_2);
		elseif ($typ_1 > 0 && $typ_2 > 0 && $typ_1 > $typ_2)
			$cecha2->atrybuty=sprintf("%s-%s,%s-%s", $typ_2,$cecha_2, $typ_1, $cecha_1);
		elseif ($typ_1 > 0 && $typ_2==0)
			$cecha2->atrybuty=sprintf("%s-%s", $typ_1, $cecha_1);
		elseif ($typ_2 > 0 && $typ_1==0)
			$cecha2->atrybuty=sprintf("%s-%s", $typ_2, $cecha_2);
	
		$cecha2->s_Id = $cecha2->SprawdzS();
		
		if($cecha2->s_Id == 0)
		{
				if($cecha2->products_id > 0 && !$cecha2->DodajStock())
					echo '<przy name="Dodawanie dostępności"  error="1" msg="'.$cecha2->errMsg[2].'" />';
				else 
					echo '<przy name="Dodawanie dostępności"  error="0" msg="OK" />';
		}
		else 
		{

			if(!$cecha2->UpdateStock())
				echo '<przy name="Zmiana dostępności"  error="1" msg="'.$cecha2->errMsg[2].'" />';
			else 
				echo '<przy name="Zmiana dostępności"  error="0" msg="OK" />';

			echo '<przy name="Dostępność istnieje."  error="0" msg="OK" />';
		}


		if(!$cecha2->UpdateStockProduktu())
		{
			echo '<przy name="Zmiana dostępności produktu"  error="1" msg="'.$cecha2->errMsg[2].'" />';
		}
		else 
		{
			echo '<przy name="Zmiana dostępności produktu"  error="0" msg="OK" />';
		}

	}
	else 
	{
		echo '<przy name="Cechy produktu."  error="1" msg="Produkt główny nie istnieje. Kod : '.$_POST['p_PN'].'" />';
	}
}

?>
